# Priceforge

This is a lightweight derivatives pricing library.

## Currently supported models
- Heston 1993
- Trolle-Schwartz 2014

## Currently supported pricing methods
- Fourier
  - Gil-Pelaez 
  - Carr-Madan
